==========
User Guide
==========

The User Guide provides an overview of the core features of the `pyquations` package, along with practical examples to help you get started. Additionally, it includes an `Articles` section with resources to further assist you in leveraging the package effectively.

.. toctree::
   :maxdepth: 2
   :hidden:

   installation
   import
   usage

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Articles

   articles/pandas